test suite reviews and discussions
 help / color / mirror / Atom feed
* [dts][PATCH V1 0/2] modify the test suite to be consistent with the test plan
@ 2023-07-04 14:15 Dukai Yuan
  2023-07-04 14:15 ` [dts][PATCH V1 1/2] tests/pvp_multi_paths_performance: keep test suite " Dukai Yuan
  2023-07-04 14:15 ` [dts][PATCH V1 2/2] conf/pvp_multi_paths_performance: update the configuration file to fit the test suite Dukai Yuan
  0 siblings, 2 replies; 3+ messages in thread
From: Dukai Yuan @ 2023-07-04 14:15 UTC (permalink / raw)
  To: dts; +Cc: Dukai Yuan

*** BLURB HERE ***

Dukai Yuan (2):
  tests/pvp_multi_paths_performance: keep test suite consistent with the test plan
  conf/pvp_multi_paths_performance: update the configuration file to fit the test suite

 conf/pvp_multi_paths_performance.cfg          | 10 ++--
 .../TestSuite_pvp_multi_paths_performance.py  | 50 +++++++++----------
 2 files changed, 30 insertions(+), 30 deletions(-)

-- 
2.31.1


^ permalink raw reply	[flat|nested] 3+ messages in thread

* [dts][PATCH V1 1/2] tests/pvp_multi_paths_performance: keep test suite consistent with the test plan
  2023-07-04 14:15 [dts][PATCH V1 0/2] modify the test suite to be consistent with the test plan Dukai Yuan
@ 2023-07-04 14:15 ` Dukai Yuan
  2023-07-04 14:15 ` [dts][PATCH V1 2/2] conf/pvp_multi_paths_performance: update the configuration file to fit the test suite Dukai Yuan
  1 sibling, 0 replies; 3+ messages in thread
From: Dukai Yuan @ 2023-07-04 14:15 UTC (permalink / raw)
  To: dts; +Cc: Dukai Yuan

Some differences exist between the test suite and the test plan, 
so modify the scripts to be consistent with the test plan.

Signed-off-by: Dukai Yuan <dukaix.yuan@intel.com>
---
 .../TestSuite_pvp_multi_paths_performance.py  | 50 +++++++++----------
 1 file changed, 25 insertions(+), 25 deletions(-)

-- 
2.31.1


^ permalink raw reply	[flat|nested] 3+ messages in thread

* [dts][PATCH V1 2/2] conf/pvp_multi_paths_performance: update the configuration file to fit the test suite
  2023-07-04 14:15 [dts][PATCH V1 0/2] modify the test suite to be consistent with the test plan Dukai Yuan
  2023-07-04 14:15 ` [dts][PATCH V1 1/2] tests/pvp_multi_paths_performance: keep test suite " Dukai Yuan
@ 2023-07-04 14:15 ` Dukai Yuan
  1 sibling, 0 replies; 3+ messages in thread
From: Dukai Yuan @ 2023-07-04 14:15 UTC (permalink / raw)
  To: dts; +Cc: Dukai Yuan

Update the configuration file to fit the test suite.

Signed-off-by: Dukai Yuan <dukaix.yuan@intel.com>
---
 conf/pvp_multi_paths_performance.cfg | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/conf/pvp_multi_paths_performance.cfg b/conf/pvp_multi_paths_performance.cfg
index 8847e436..33f35b14 100644
--- a/conf/pvp_multi_paths_performance.cfg
+++ b/conf/pvp_multi_paths_performance.cfg
@@ -6,11 +6,11 @@ accepted_tolerance = 2
 expected_throughput = {
     'test_perf_pvp_virtio11_vectorized': {64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}},
     'test_perf_pvp_virtio11_mergeable': {64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}},
-    'test_perf_pvp_virtio11_normal': {64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}},
+    'test_perf_pvp_virtio11_non_mergeable': {64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}},
     'test_perf_pvp_virtio11_inorder_mergeable': {64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}},
-    'test_perf_pvp_virtio11_inorder_normal': {64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}},
+    'test_perf_pvp_virtio11_inorder_non_mergeable': {64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}},
     'test_perf_pvp_inorder_mergeable': {64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}},
-    'test_perf_pvp_inorder_normal':{64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}},
+    'test_perf_pvp_inorder_non_mergeable':{64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}},
     'test_perf_pvp_mergeable': {64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}},
-    'test_perf_pvp_normal':{64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}},
-    'test_perf_pvp_vector_rx': {64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}}}
+    'test_perf_pvp_non_mergeable':{64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}},
+    'test_perf_pvp_vectorized_rx': {64: {1024: 0.000}, 128: {1024: 0.000}, 256: {1024: 0.000}, 512: {1024: 0.000}, 1024: {1024: 0.000}, 1518: {1024: 0.000}}}
diff --git a/tests/TestSuite_pvp_multi_paths_performance.py b/tests/TestSuite_pvp_multi_paths_performance.py
index f704f29b..36d74a63 100644
--- a/tests/TestSuite_pvp_multi_paths_performance.py
+++ b/tests/TestSuite_pvp_multi_paths_performance.py
@@ -302,7 +302,7 @@ class TestPVPMultiPathsPerformance(TestCase):
 
     def test_perf_pvp_virtio11_mergeable(self):
         """
-        performance for PVP virtio 1.1 Mergeable Path.
+        Case 1:performance for PVP virtio 1.1 mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -314,16 +314,16 @@ class TestPVPMultiPathsPerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1_mergeable on")
+        self.send_and_verify("virtio1.1_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_pvp_virtio11_normal(self):
+    def test_perf_pvp_virtio11_non_mergeable(self):
         """
         performance for PVP virtio1.1 Normal Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -335,7 +335,7 @@ class TestPVPMultiPathsPerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1_normal")
+        self.send_and_verify("virtio1.1_non_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -344,7 +344,7 @@ class TestPVPMultiPathsPerformance(TestCase):
 
     def test_perf_pvp_virtio11_inorder_mergeable(self):
         """
-        performance for PVP virtio 1.1 inorder Mergeable Path.
+        Case 8:performance for PVP virtio 1.1 inorder mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -356,16 +356,16 @@ class TestPVPMultiPathsPerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1_inorder_mergeable on")
+        self.send_and_verify("virtio1.1_inorder_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_pvp_virtio11_inorder_normal(self):
+    def test_perf_pvp_virtio11_inorder_non_mergeable(self):
         """
         performance for PVP virtio1.1 inorder Normal Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -377,7 +377,7 @@ class TestPVPMultiPathsPerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1_inorder_normal")
+        self.send_and_verify("virtio1.1_inorder_non_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -386,7 +386,7 @@ class TestPVPMultiPathsPerformance(TestCase):
 
     def test_perf_pvp_virtio11_vectorized(self):
         """
-        performance for PVP virtio1.1 Vectorized Path.
+        Case 10:performance for PVP virtio1.1 vectorized Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -398,7 +398,7 @@ class TestPVPMultiPathsPerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virtio_1.1_inorder_normal")
+        self.send_and_verify("virtio1.1_vectorized")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -407,7 +407,7 @@ class TestPVPMultiPathsPerformance(TestCase):
 
     def test_perf_pvp_inorder_mergeable(self):
         """
-        performance for PVP In_order mergeable Path.
+        Case 3:performance for PVP Inorder mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -419,16 +419,16 @@ class TestPVPMultiPathsPerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("inoder mergeable on")
+        self.send_and_verify("virito1.0_inoder_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_pvp_inorder_normal(self):
+    def test_perf_pvp_inorder_non_mergeable(self):
         """
-        performance for PVP In_order Normal Path.
+        Case 4:performance for PVP Inorder non-mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -440,7 +440,7 @@ class TestPVPMultiPathsPerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("inoder mergeable off")
+        self.send_and_verify("virito1.0_inoder_non_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -449,7 +449,7 @@ class TestPVPMultiPathsPerformance(TestCase):
 
     def test_perf_pvp_mergeable(self):
         """
-        performance for PVP Mergeable Path.
+        Case 5:performance for PVP mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -461,16 +461,16 @@ class TestPVPMultiPathsPerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virito mergeable")
+        self.send_and_verify("virito1.0_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_pvp_normal(self):
+    def test_perf_pvp_non_mergeable(self):
         """
-        performance for PVP Normal Path.
+        Case 6:performance for PVP non_mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -482,16 +482,16 @@ class TestPVPMultiPathsPerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virito normal")
+        self.send_and_verify("virito1.0_non_mergeable")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_pvp_vector_rx(self):
+    def test_perf_pvp_vectorized_rx(self):
         """
         performance for PVP Vector_RX Path
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()["expected_throughput"][
@@ -503,7 +503,7 @@ class TestPVPMultiPathsPerformance(TestCase):
         }
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
-        self.send_and_verify("virito vector rx")
+        self.send_and_verify("virito1.0_vectorized_rx")
         self.close_all_testpmd()
         self.logger.info("result of all framesize result")
         self.result_table_print()
@@ -314,16 +314,16 @@ class TestPVPMultiPathsPerformance(TestCase):
         """
-        performance for PVP virtio1.1 Normal Path.
+        Case 2:performance for PVP virtio1.1 non-mergeable Path.
         """
         self.test_target = self.running_case
@@ -356,16 +356,16 @@ class TestPVPMultiPathsPerformance(TestCase):
         """
-        performance for PVP virtio1.1 inorder Normal Path.
+        Case 9:performance for PVP virtio1.1 inorder non-mergeable Path.
         """
         self.test_target = self.running_case
@@ -482,16 +482,16 @@ class TestPVPMultiPathsPerformance(TestCase):
         """
-        performance for PVP Vector_RX Path
+        Case 7:performance for PVP vectorized_rx Path
         """
         self.test_target = self.running_case
-- 
2.31.1


^ permalink raw reply	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2023-07-04  6:39 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2023-07-04 14:15 [dts][PATCH V1 0/2] modify the test suite to be consistent with the test plan Dukai Yuan
2023-07-04 14:15 ` [dts][PATCH V1 1/2] tests/pvp_multi_paths_performance: keep test suite " Dukai Yuan
2023-07-04 14:15 ` [dts][PATCH V1 2/2] conf/pvp_multi_paths_performance: update the configuration file to fit the test suite Dukai Yuan

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).